@@ -9,8 +9,8 @@ module ActionMailer
   module VERSION
     MAJOR = 7
     MINOR = 1
-    TINY  = 4
-    PRE   = nil
+    TINY  = 5
+    PRE   = "1"
 
     STRING = [MAJOR, MINOR, TINY, PRE].compact.join(".")
   end
